# Robots

The Space Robotics Bench provides a diverse set of robots for simulating various scenarios:

- [**Manipulators**](manipulators.md) - Robotic arms
- [**Mobile Robots**](mobile_robots.md) - Wheeled rovers, legged robots, aerial vehicles, spacecraft, ...
- [**Mobile Manipulators**](mobile_manipulators.md) - All `mobile robot + manipulator` combinations, humanoids, ...
